==> yaru-theme_21.04.1.tar.xz: yaru-theme-21.04.1/.github/ISSUE_TEMPLATE/gnome-shell_bug_report.md <==
---
name: Gnome-shell bug report
about: Report a bug related to our Gnome-shell theme
title: ''
labels: 'Area: GNOME-shell'
assignees: ''
---

<!--
Thank you for contributing to Yaru, the Ubuntu's default theme made by the Community.
If you found a bug please consider to fill below information, this will help us to understand the problem and we don't bother you with other questions :)

(NOTE: you can remove all the text inside comment quotes)
-->

<!--===================
     World 1 - Stage 1
    ===================-->

<!-- Thank you for taking the time of write this bug report, these are the minimum info we need: -->

**Expected Behavior**

<!-- (What you were trying to do)-->

**Actual Behavior**

<!-- (What happened instead)-->

**Steps to Reproduce the Problem**

<!--
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See problem
-->

**System information**

<!--
- Shell version: (run `$ gnome-shell --version`) [e.g. 3.36.3]
- OS version: (run `$ lsb_release -a`) [e.g. Ubuntu 20.04.1]
-->

**Yaru version**

<!--
Please report the Yaru version in your system using one of the following commands:

* If you just use the default Ubuntu session (since Ubuntu 18.10)

    `$ apt show yaru-theme-gnome-shell`

* If you installed Yaru via Snap (Ubuntu 18.04 only)

    `$ snap info communitheme`

* If you installed from the sources, go the Yaru folder and copy the output of the following terminal command instead

    `$ git describe`
-->

<!--===================
     World 1 - Stage 2
    ===================-->

<!-- Do you really want to help us? Please also do these additional things: -->

**Screenshots**

<!-- (Insert here some screenshots to help explain better your problem)-->

**Upstream check**

 <!-- Please also check if the problem also occurs with the Adwaita upstream theme. To do that, firstly install Gnome session:

    `$ sudo apt install gnome-session`

Then log-out, reconnect you using the Gnome session (click on the gear for switch), and check if the problem is still there. -->

<!--==================================
     World 1 - 🔥 🏰 Boss stage 🏰 🔥
    ==================================-->

<!--
Do you know how to fix that problem? Maybe could you create a PR!
To begin this quest, please firstly have a look to the Contributing doc file: https://github.com/ubuntu/yaru/blob/master/CONTRIBUTING.md
-->

<!-- Thanks a lot! -->

==> yaru-theme_22.04.5.tar.xz: yaru-theme-22.04.5/.github/ISSUE_TEMPLATE/gnome-shell_bug_report.md <==
---
name: Gnome-shell bug report
about: Report a bug related to our Gnome-shell theme
title: ''
labels: 'Area: GNOME-shell'
assignees: ''
---

<!--
Thank you for contributing to Yaru, the Ubuntu's default theme made by the Community.
If you found a bug please consider to fill below information, this will help us to understand the problem and we don't bother you with other questions :)

(NOTE: you can remove all the text inside comment quotes)
-->

<!--===================
     World 1 - Stage 1
    ===================-->

<!-- Thank you for taking the time of write this bug report, these are the minimum info we need: -->

**Expected Behavior**

<!-- (What you were trying to do)-->

**Actual Behavior**

<!-- (What happened instead)-->

**Steps to Reproduce the Problem**

<!--
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See problem
-->

**System information**

<!--
- Shell version: (run `$ gnome-shell --version`) [e.g. 3.36.3]
- OS version: (run `$ lsb_release -a`) [e.g. Ubuntu 20.04.1]
-->

**Yaru version**

<!--
Please report the Yaru version in your system using one of the following commands:

* If you just use the default Ubuntu session

    `$ apt show yaru-theme-gnome-shell`

* If you installed from the sources, go the Yaru folder and copy the output of the following terminal command instead

    `$ git describe`
-->

<!--===================
     World 1 - Stage 2
    ===================-->

<!-- Do you really want to help us? Please also do these additional things: -->

**Screenshots**

<!-- (Insert here some screenshots to help explain better your problem)-->

**Upstream check**

 <!-- Please also check if the problem also occurs with the Adwaita upstream theme. To do that, firstly install Gnome session:

    `$ sudo apt install gnome-session`

Then log-out, reconnect you using the Gnome session (click on the gear for switch), and check if the problem is still there. -->

<!--==================================
     World 1 - 🔥 🏰 Boss stage 🏰 🔥
    ==================================-->

<!--
Do you know how to fix that problem? Maybe could you create a PR!
To begin this quest, please firstly have a look to the Contributing doc file: https://github.com/ubuntu/yaru/blob/master/CONTRIBUTING.md
-->

<!-- Thanks a lot! -->
